TunInboundSettings class

Inheritance
Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

TunInboundSettings({String? name, int mtu = 1500, int userLevel = 0})
TunInboundSettings.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
mtu int
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userLevel int
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited