Mux class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Mux({bool? enabled, int? concurrency, int? xudpConcurrency, String? xudpProxyUDP443})
const
Mux.fromJson(Map<String, dynamic> json)
factory

Properties

concurrency int?
final
enabled bool?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
xudpConcurrency int?
final
xudpProxyUDP443 String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited