ShadowSocksOutboundSettings class

Inheritance
Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

ShadowSocksOutboundSettings({String? email, String? address, int? port, EncryptionMethod? method, String? password, bool? uot, int? uoTVersion, List<ShadowSocksServer>? servers, int? level})
const
ShadowSocksOutboundSettings.fromJson(Map<String, dynamic> json)
factory

Properties

address String?
final
email String?
final
hashCode int
The hash code for this object.
no setterinherited
level int?
finalinherited
method EncryptionMethod?
final
password String?
final
port int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
servers List<ShadowSocksServer>?
final
uot bool?
final
uoTVersion int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited