ShadowSocksServer class

ShadowSocks server entry.

Inheritance
Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

ShadowSocksServer({required String address, required int port, String? email, required String password, EncryptionMethod? method})
const
ShadowSocksServer.fromJson(Map<String, dynamic> json)
factory

Properties

address String
Server address (IPv4, IPv6, or domain).
finalinherited
email String?
Optional email identifier.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
method EncryptionMethod?
Encryption method.
final
password String
Required password.
finalinherited
port int
Server port.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited