RoutingConfig class

Configures routing. Specifies rules to route connections through different outbounds.

Docs: https://xtls.github.io/config/routing.html

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

RoutingConfig({RoutingDomainStrategy? domainStrategy, List<RoutingRule> rules = const [], List<RoutingBalancer> balancers = const []})
RoutingConfig.fromJson(Map<String, dynamic> json)
factory

Properties

balancers List<RoutingBalancer>
Array of load balancer configurations.
getter/setter pair
domainStrategy RoutingDomainStrategy?
Domain name resolution strategy. Default: AsIs.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
rules List<RoutingRule>
Array of routing rules.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited