CustomSockopt class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CustomSockopt({OperatingSystem? system, required String type, String? level, String? opt, String? value})
const
CustomSockopt.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
level String?
final
opt String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
system OperatingSystem?
final
type String
final
value String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited