XHttpDownloadSettings class

Download settings for XHTTP.

Inheritance
Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

XHttpDownloadSettings({String? address, int? port, StreamNetwork network = StreamNetwork.raw, StreamSecurity security = StreamSecurity.none, TlsSettings? tlsSettings, RealitySettings? realitySettings, RawSettings? rawSettings, XHttpSettings? xhttpSettings, KcpSettings? kcpSettings, GrpcSettings? grpcSettings, WsSettings? wsSettings, HttpUpgradeSettings? httpUpgradeSettings, HysteriaSettings? hysteriaSettings, Sockopt? sockopt})
XHttpDownloadSettings.fromJson(Map<String, dynamic> json)
factory

Properties

address String?
getter/setter pair
grpcSettings GrpcSettings?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
httpUpgradeSettings HttpUpgradeSettings?
getter/setter pairinherited
hysteriaSettings HysteriaSettings?
getter/setter pairinherited
kcpSettings KcpSettings?
getter/setter pairinherited
network StreamNetwork
finalinherited
port int?
getter/setter pair
rawSettings RawSettings?
getter/setter pairinherited
realitySettings RealitySettings?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
security StreamSecurity
finalinherited
sockopt Sockopt?
getter/setter pairinherited
tlsSettings TlsSettings?
getter/setter pairinherited
wsSettings WsSettings?
getter/setter pairinherited
xhttpSettings XHttpSettings?
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited