MLKEM768Data class

Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

MLKEM768Data({required String seed, required String client, required String hash})
MLKEM768Data.fromJson(Map<String, dynamic> json)
factory

Properties

client String
final
hash String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seed String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited