Transfer class

Constructors

Transfer.fromPointer(Pointer<Void> pointer)
factory

Properties

code int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message String
no setter
nullptr bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
no setter
type ContentType
getter/setter pair

Methods

getPayload() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited