XrayLibCore class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateCert(GenerateCertOptions options)
→ TlsCerts
-
Generating TLS certificates
options — Options for generation
override
-
generateMLDSA65(String input)
→ MLDSA65Data
-
Generate key pair for ML-DSA-65 post-quantum signature (REALITY)
input — Seed in base64 encoding
override
-
generateMLKEM768(String input)
→ MLKEM768Data
-
Generate key pair for ML-KEM-768 post-quantum key exchange (VLESS Encryption)
input — Seed in base64 encoding
override
-
generateUuidV4()
→ String
-
Generate UUIDv4 (VLESS)
override
-
generateUuidV5(String input)
→ String
-
Generate UUIDv5 (VLESS)
input — Initial word (30 bytes)
override
-
generateVlessAuthentication()
→ VlessAuthentication
-
Generate decryption/encryption json pair (VLESS Encryption)
Returns X25519 (non‑PQ) and ML‑KEM‑768 (PQ)
override
-
generateX25519Keys(String privateKey)
→ X25519Data
-
Generate key pair for X25519 key exchange (REALITY, VLESS Encryption)
privateKey — Private key (base64.RawURLEncoding)
override
-
generateX25519WGKeys(String privateKey)
→ X25519Data
-
Generate key pair for X25519 key exchange for Wireguard
privateKey — Private key (base64.RawURLEncoding)
override
-
getCertChainHash(String certPem)
→ String
-
Calculate TLS certificates hash
certPem — file or cert content
override
-
isStarted()
→ bool
-
Check if the xray-core server instance.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
ping(int port, String testingUrl)
→ Future<int>
-
Test network speed
port — Port to test
testingUrl — URL to test (need response 200 or 204 code)
override
-
pingConfig(XrayConfig config, List<int> ports, String testingUrl)
→ Future<List<PingResult>>
-
Test network speed
config — Xray config
ports — Ports to test
testingUrl — URL to test (need response 200 or 204 code)
override
-
start(XrayConfig config, {String? uuid, Map<String, String> env = const {}})
→ void
-
Start the xray-core server by config.
override
-
startAsync(XrayConfig config, {String? uuid, Map<String, String> env = const {}})
→ Future<void>
-
override
-
stop({String? uuid})
→ void
-
Stop the xray-core server.
override
-
stopAsync({String? uuid})
→ Future<void>
-
override
-
toString()
→ String
-
A string representation of this object.
inherited
-
version()
→ String
-
Get the xray core version
override