packages/share/v2ray/helpers/common library
Functions
-
getAddressOrDefault(
String? listen) → String -
getClientByEmail<
T> (List< T> clients, String? email, String inboundTag) → T -
Find client by
emailin providedclientslist or throw a clear error. Find client byemailin providedclientslist or throw a clear error. -
getRemark(
Inbound inbound) → String -
parseAndValidate(
String config, List< String> expectedSchemes) → Uri -
Parse
configinto Uri and validate scheme equalsexpectedScheme. -
parseProtocol(
String link) → String -
remarkFromFragment(
String fragment, String prefix, int port) → String -
Build outbound remark from
fragment. If fragment contains a remark it is expected to start with a leading char and will be returned without it. Otherwise returns$prefix-$port. -
searchHost(
Map< String, dynamic> ? headers) → String