VMessInbound class
Constructors
- VMessInbound({String? listen, required Port port, required String tag, InboundSniffing? sniffing, InboundAllocate? allocate, required StreamSettings? streamSettings, required VMessInboundSettings settings})
-
VMessInbound.fromJson(Map<
String, dynamic> json) -
factory
Properties
- allocate ↔ InboundAllocate?
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- listen ↔ String?
-
getter/setter pairinherited
- port ↔ Port
-
getter/setter pairinherited
- protocol ↔ Protocol
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → VMessInboundSettings
-
final
- sniffing ↔ InboundSniffing?
-
getter/setter pairinherited
- streamSettings ↔ StreamSettings
-
getter/setter pairinherited
- tag ↔ String
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited