FreedomOutboundSettings class
- Inheritance
-
- Object
- WithUserLevel
- FreedomOutboundSettings
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
-
FreedomOutboundSettings({DomainStrategy? domainStrategy, String? redirect, Map<
String, String> ? fragment, List<Map< ? noises, int? proxyProtocol, int userLevel = 0})String, String> > -
FreedomOutboundSettings.fromJson(Map<
String, dynamic> json) -
factory
Properties
- domainStrategy ↔ DomainStrategy?
-
getter/setter pair
-
fragment
↔ Map<
String, String> ? -
Fragmentation settings.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
noises
↔ List<
Map< ?String, String> > -
UDP noise configuration.
getter/setter pair
- proxyProtocol ↔ int?
-
PROXY protocol version.
getter/setter pair
- redirect ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userLevel ↔ int
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited