BalancerStrategySettings class
Settings for load balancing strategies.
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
-
BalancerStrategySettings({int? expected, String? maxRTT, double? tolerance, List<
String> ? baselines, List<BalancerCost> ? costs}) -
BalancerStrategySettings.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
baselines
→ List<
String> ? -
Max acceptable RTT deviation.
final
-
costs
→ List<
BalancerCost> ? -
Weight configuration.
final
- expected → int?
-
Number of optimal nodes.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxRTT → String?
-
Max allowed RTT.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tolerance → double?
-
Max allowed failure percentage.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited