StreamSettings class
- Implementers
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
- StreamSettings({StreamNetwork network = StreamNetwork.raw, StreamSecurity security = StreamSecurity.none, TlsSettings? tlsSettings, RealitySettings? realitySettings, RawSettings? rawSettings, XHttpSettings? xhttpSettings, KcpSettings? kcpSettings, GrpcSettings? grpcSettings, WsSettings? wsSettings, HttpUpgradeSettings? httpUpgradeSettings, HysteriaSettings? hysteriaSettings, Sockopt? sockopt})
-
StreamSettings.fromJson(Map<
String, dynamic> json) -
factory
Properties
- grpcSettings ↔ GrpcSettings?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpUpgradeSettings ↔ HttpUpgradeSettings?
-
getter/setter pair
- hysteriaSettings ↔ HysteriaSettings?
-
getter/setter pair
- kcpSettings ↔ KcpSettings?
-
getter/setter pair
- network → StreamNetwork
-
final
- rawSettings ↔ RawSettings?
-
getter/setter pair
- realitySettings ↔ RealitySettings?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- security → StreamSecurity
-
final
- sockopt ↔ Sockopt?
-
getter/setter pair
- tlsSettings ↔ TlsSettings?
-
getter/setter pair
- wsSettings ↔ WsSettings?
-
getter/setter pair
- xhttpSettings ↔ XHttpSettings?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited