WsSettings class
WebSocket configuration for the current connection.
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
Properties
- acceptProxyProtocol → bool?
-
Accept PROXY protocol for inbound connections.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> ? -
Custom HTTP headers (string → string).
final
- heartbeatPeriod → int?
-
Interval for sending Ping frames (ms). 0 or null = disabled.
final
- host → String?
-
Host header sent in WebSocket handshake.
final
- path → String?
-
WebSocket path (default "/").
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited