XHttpSettings class
XHTTP configuration for the current connection.
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
-
XHttpSettings({String? host, String? path, XHttpMode mode = XHttpMode.auto, XHttpExtraSettings extra = const XHttpExtraSettings(), Map<
String, String> ? headers}) -
const
-
XHttpSettings.fromJson(Map<
String, dynamic> json) -
factory
Properties
- extra → XHttpExtraSettings
-
Extra shared settings.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> ? -
Additional HTTP headers.
final
- host → String?
-
Host header in HTTP request.
final
- mode → XHttpMode
-
Mode for sending data (client-only).
final
- path → String?
-
HTTP path used by the client.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited